@@ -717,7 +717,11 @@ bool ObjectPrototype::lazy_define_gobject_property(JSContext* cx,
     JS::RootedValue private_id(cx, JS::StringValue(JSID_TO_STRING(id)));
     if (!gjs_define_property_dynamic(
             cx, obj, name, "gobject_prop", &ObjectBase::prop_getter,
-            &ObjectBase::prop_setter, private_id, GJS_MODULE_PROP_FLAGS))
+            &ObjectBase::prop_setter, private_id,
+            // Make property configurable so that interface properties can be
+            // overridden by GObject.ParamSpec.override in the class that
+            // implements them
+            GJS_MODULE_PROP_FLAGS & ~JSPROP_PERMANENT))
         return false;
 
     *resolved = true;
@@ -1939,9 +1943,8 @@ bool ObjectPrototype::to_string_impl(JSContext* cx, const JS::CallArgs& args) {
 static const struct JSClassOps gjs_object_class_ops = {
     &ObjectBase::add_property,
     nullptr,  // deleteProperty
-    nullptr,  // getProperty
-    nullptr,  // setProperty
     nullptr,  // enumerate
+    nullptr,  // newEnumerate
     &ObjectBase::resolve,
     nullptr,  // mayResolve
     &ObjectBase::finalize,
@@ -1977,11 +1980,11 @@ JSPropertySpec gjs_object_instance_proto_props[] = {
 };
 
 JSFunctionSpec gjs_object_instance_proto_funcs[] = {
-    JS_FS("_init", &ObjectBase::init, 0, 0),
-    JS_FS("connect", &ObjectBase::connect, 0, 0),
-    JS_FS("connect_after", &ObjectBase::connect_after, 0, 0),
-    JS_FS("emit", &ObjectBase::emit, 0, 0),
-    JS_FS("toString", &ObjectBase::to_string, 0, 0),
+    JS_FN("_init", &ObjectBase::init, 0, 0),
+    JS_FN("connect", &ObjectBase::connect, 0, 0),
+    JS_FN("connect_after", &ObjectBase::connect_after, 0, 0),
+    JS_FN("emit", &ObjectBase::emit, 0, 0),
+    JS_FN("toString", &ObjectBase::to_string, 0, 0),
     JS_FS_END};
 
 bool
